@@ -1,3 +1,3 @@
-from .progressbars import *
+from .progress import *
 from .interpreters import *
 from .performances import *
\ No newline at end of file
