@@ -20,21 +20,21 @@ class GeneralTaskModule(LightningModule):
 
     def training_step(self, batch, batch_nb):               # 训练步
         loss, preds, targets = self.do_forward(batch)
-        self.log('train_loss', loss.detach(), prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
+        self.log('train_loss', loss, prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
         self.do_metric(preds, targets, 'train', self.log)
         self.messages['train_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         return loss
 
     def validation_step(self, batch, batch_nb):             # 验证步
         loss, preds, targets = self.do_forward(batch)
-        self.log('val_loss', loss.detach(), prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
+        self.log('val_loss', loss, prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
         self.do_metric(preds, targets, 'val', self.log)
         self.messages['val_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         return {'val_loss': loss}
 
     def test_step(self, batch, batch_nb):                   # 测试步
         loss, preds, targets = self.do_forward(batch)
-        self.log('test_loss', loss.detach(), prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
+        self.log('test_loss', loss, prog_bar=True, on_step=self.on_step, on_epoch=self.on_epoch)
         self.do_metric(preds, targets, 'test', self.log)
         self.messages['test_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         return {'test_loss': loss}
@@ -58,4 +58,4 @@ class GeneralTaskModule(LightningModule):
             else:
                 name = metric.__name__
                 on_step, on_epoch = True, True
-            log(f"{state}_{name}", result.detach(), prog_bar=True, on_step=on_step, on_epoch=on_epoch)
+            log(f"{state}_{name}", result, prog_bar=True, on_step=on_step, on_epoch=on_epoch)
